from setuptools import setup, find_packages

setup(
    name='KunTimeChange',
    version='11.5',
    packages=find_packages(),
    install_requires=[
        
    ],
    author='W0518',
    author_email='2647346053@qq.com',
    description='A brief description of your package',
    license='MIT',
    keywords='sample setuptools development',
    url='https://github.com/ziyin-wang/ikuntime'
)
